==> openshift-model-hive-5.12.4-sources.jar: io/fabric8/openshift/api/model/hive/v1/DNSZoneBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DNSZoneBuilder extends io.fabric8.openshift.api.model.hive.v1.DNSZoneFluentImpl<io.fabric8.openshift.api.model.hive.v1.DNSZoneBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.DNSZone,io.fabric8.openshift.api.model.hive.v1.DNSZoneBuilder>{
  public DNSZoneBuilder() {
    this(false);
  }
  public DNSZoneBuilder(java.lang.Boolean validationEnabled) {
    this(new DNSZone(), validationEnabled);
  }
  public DNSZoneBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSZoneBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DNSZone(), validationEnabled);
  }
  public DNSZoneBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.DNSZone instance) {
    this(fluent, instance, false);
  }
  public DNSZoneBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.DNSZone instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSZoneBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZone instance) {
    this(instance,false);
  }
  public DNSZoneBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZone instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.DNSZoneFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.DNSZone build() {
    DNSZone buildable = new DNSZone(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSZoneBuilder that = (DNSZoneBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.4.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/DNSZoneBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DNSZoneBuilder extends DNSZoneFluentImpl<DNSZoneBuilder> implements VisitableBuilder<DNSZone,DNSZoneBuilder>{
  public DNSZoneBuilder() {
    this(false);
  }
  public DNSZoneBuilder(Boolean validationEnabled) {
    this(new DNSZone(), validationEnabled);
  }
  public DNSZoneBuilder(DNSZoneFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSZoneBuilder(DNSZoneFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DNSZone(), validationEnabled);
  }
  public DNSZoneBuilder(DNSZoneFluent<?> fluent,DNSZone instance) {
    this(fluent, instance, false);
  }
  public DNSZoneBuilder(DNSZoneFluent<?> fluent,DNSZone instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSZoneBuilder(DNSZone instance) {
    this(instance,false);
  }
  public DNSZoneBuilder(DNSZone instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  DNSZoneFluent<?> fluent;
  Boolean validationEnabled;
  public DNSZone build() {
    DNSZone buildable = new DNSZone(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
